@@ -951,7 +951,19 @@ class Player(Repeatable):
 
                 if key in kwargs:
 
-                    new_event[key] = self.unpack(PGroup(kwargs[key]))
+                    item = kwargs[key]
+
+                    if isinstance(item, PGroupPrime):
+
+                        new_event[key] = self.unpack(item)
+
+                    elif isinstance(item, PGroup):
+
+                        new_event[key] = self.unpack(PGroup([item]))
+
+                    else:
+
+                        new_event[key] = self.unpack(PGroup(item))
 
                 elif len(attributes[key]) > 0:
 
@@ -961,9 +973,11 @@ class Player(Repeatable):
 
             dur = float(kwargs.get("dur", new_event["dur"])) / n
 
+            new_event["dur"] = dur
+
             # Get PGroup delays
 
-            new_event["delay"] = PGroup([PGroup([dur * (i+1) for i in range(n-1)]) for x in range(self.get_event_length(new_event))])
+            new_event["delay"] = PGroup([dur * (i+1) for i in range(max(n, self.get_event_length(new_event)))])
 
             new_event = self.get_prime_funcs(new_event)
 
@@ -1048,6 +1062,11 @@ class Player(Repeatable):
             self.pan=0
             self.pshift=0
         return self
+
+    def seconds(self):
+        """ Sets the player bpm to 60 so duration will be measured in seconds """
+        self.bpm=60
+        return self
     
     def slider(self, start=0, on=1):
         """ Creates a glissando effect between notes """
@@ -1501,7 +1520,7 @@ class Player(Repeatable):
 
                 if len(event['sus']) > 1:
 
-                    min_sus = min(event['sus'])
+                    min_sus = min(event['sus']) if min(event['sus']) else 1
 
                     offset = PGroup([(sus / min_sus) for sus in event["sus"]])
 
